import { CrossmintSDKError } from '@crossmint/common-sdk-base';
export { CrossmintErrors, CrossmintSDKError, PaymentErrors, SmartWalletErrorCode, WalletErrorCode } from '@crossmint/common-sdk-base';

declare class CrossmintServiceError extends CrossmintSDKError {
    status?: number;
    constructor(message: string, status?: number);
}
declare class NotAuthorizedError extends CrossmintSDKError {
    constructor(message: string);
}
declare class JWTExpiredError extends NotAuthorizedError {
    readonly code: string;
    /**
     * The expiry time of the JWT as an ISO 8601 timestamp.
     */
    readonly expiredAt: string;
    constructor(expiredAt: Date);
}
declare class JWTInvalidError extends NotAuthorizedError {
    readonly code: string;
    constructor();
}
declare class JWTDecryptionError extends NotAuthorizedError {
    readonly code: string;
    constructor();
}
declare class JWTIdentifierError extends NotAuthorizedError {
    readonly code: string;
    readonly identifierKey: string;
    constructor(identifierKey: string);
}
declare class OutOfCreditsError extends CrossmintSDKError {
    constructor();
}

export { CrossmintServiceError, JWTDecryptionError, JWTExpiredError, JWTIdentifierError, JWTInvalidError, NotAuthorizedError, OutOfCreditsError };
